#
# spec file for package octave-forge-interval
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define octpkg  interval
Name:           octave-forge-%{octpkg}
Version:        3.2.1
Release:        1.4
Summary:        Real-valued interval arithmetic for Octave
License:        GPL-3.0-or-later
Group:          Productivity/Scientific/Math
URL:            https://octave.sourceforge.io/interval/
Source0:        http://downloads.sourceforge.net/octave/%{octpkg}-%{version}.tar.gz
BuildRequires:  gcc-c++
BuildRequires:  hdf5-devel
BuildRequires:  mpfr-devel >= 3.1.0
BuildRequires:  octave-devel
Requires:       octave-cli >= 3.8.2

%description
The interval package for real-valued interval arithmetic allows to
evaluate functions over subsets of their domain.  All results are verified,
because interval computations automatically keep track of any errors.

These concepts can be used to handle uncertainties, estimate arithmetic errors
and produce reliable results.  Also it can be applied to computer-assisted
proofs, constraint programming, and verified computing.

The implementation is based on interval boundaries represented by binary64
numbers and is conforming to IEEE Std 1788-2015, IEEE standard for interval
arithmetic.

This is part of Octave-Forge project.

%prep
%setup -q -c %{name}-%{version}
%octave_pkg_src

%build
%octave_pkg_build

%install
%octave_pkg_install
# FIXME
# Remove documentation sources, building requires interval package installed
rm -r %{buildroot}%{octpackages_dir}/%{octpkg}-%{version}/doc

%check
%octave_pkg_test

%post
%octave --eval "pkg rebuild"

%postun
%octave --eval "pkg rebuild"

%files
%defattr(-,root,root)
%{octpackages_dir}/%{octpkg}-%{version}
%{octlib_dir}/%{octpkg}-%{version}

%changelog
* Tue Feb 22 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 3.2.1:
  * The minimum required Octave version has been increased from
    3.8.0 to 4.2.0.
  * subsref: Access to interval properties using field syntax, e.
    g., ‘x.inf’ and ‘x.sup’, has been fixed for Octave 5.1 and
    later on Windows (bug #59334).
  * disp: Fix runtime errors in Octave 6 and later, when the
    function parameter is not a named variable (bug #59334).
  * numel: Fix runtime warnings in Octave 6 and later, when the
    function is called with only one parameter.
  * Syntax errors caused by increment and decrement operators in
    Octave 7 and later have been fixed (bug #59334).
  * Interval constants for ‘pi’ and ‘e’ in Octave 7 and later have
    been fixed.  This also fixes several trigonometric functions,
    which have produced wrong results in Octave 7.
  * Compilation errors during package installation with Octave 8
    and later have been fixed (bug #61568).
- Update URL to the correct upstream.
* Wed Jul 18 2018 badshah400@gmail.com
- Update to version 3.2.0:
  * Fixed a regression where decorated intervals could no longer
    be used in Octave 4.4 (bug #53331).
  * intervaltotext: A change in Octave 4.4 has removed the
    possibility to increase Octave’s output precision beyond 16
    decimal digits (bug #53456), which has made it impossible to
    output intervals with a higher accuracy.  The function
    ‘intervaltotext’ has been reimplemented with several new
    format options to customize the format and accuracy of the
    interval literal.  All recommended conversion specifiers from
    IEEE Std 1788-2015 are now supported, e. g., intervals can be
    printed in uncertain form.
  * printf, fprintf, sprintf: New functions to produce formatted
    output with interval literals.
  * numel: Added support for additional arguments to compute the
    number of elements after indexing an interval array.  This
    allows combined indexing expressions of the form ‘x(1:2).inf’.
  * Fixed several warnings during package installation.
* Tue Aug 22 2017 dmitry_r@opensuse.org
- Update to version 3.0.0
  * Support for N-dimensional arrays of intervals
  See `news interval` for detailed changelog
* Thu Nov 24 2016 dmitry_r@opensuse.org
- Update to version 2.0.0
  * Operations from IEEE Std 1788-2015 which trigger an "exception"
    shall return a value nonetheless. Conformance has been improved
    in this new version, but may break compatibility with previous versions.
  * Interval package comprises functions from VERSOFT, a verification
    software package
* Tue Jun  7 2016 dmitry_r@opensuse.org
- Update to version 1.5.0
  * norm: Added subordinate matrix norms and the max norm
  * strictsubset: New interval comparison function
* Sat Oct  3 2015 dmitry_r@opensuse.org
- Update to version 1.2.0
  * The output format for intervals has been changed.  The number of
    decimal places now respects what has been set by the user with the
    ‘format short’ or ‘format long’ command, and is much shorter by
    default.  Also it is possible to use ‘format hex’.  The old format
    can be accessed with the ‘intervaltotext’ function.
  * fminsearch: New optimizer function for finding the minimum value of
    a function over interval constraints using the Skelboe-Moore
    algorithm
  * fzero: Changed function parameters to support optimset options
  * power: Improved speed of the general interval power function and
    monomials with the notation x .^ n
  * plot, plot3: Added support for colormaps
* Thu Aug 13 2015 dmitry_r@opensuse.org
- Update to version 1.1.0
  * meshgrid, mince: New utility functions to help plotting of
    interval functions
  * linspace: New interval arithmetic function
  * intersect, max, min, union: Allow evaluation as aggregate
    functions within an interval matrix along a common dimension
  * Improvements in the documentation
* Sat Jun 20 2015 dmitry_r@opensuse.org
- Update to version 1.0.0
  * IEEE 1788, the standard for interval arithmetic, was approved on
    June 11.  To mark the occasion, the major version number has been
    raised.
  * All interval constructors have been extended to create interval
    matrices from a single string.  Commas or spaces may be used as a
    column separator (consecutive separators are trimmed).  Semicolon
    and new line characters can be used as a row separator.
  * hdist, idist, sdist, smig: New interval numeric functions
  * User manual: Relicensed under GPL, added examples from the former
    Octave SIMP package, and various minor improvements.
  * Documentation was relicenced to GPL-3.0
  Bugfixes
  * mtimes: Fixed matrix-vector multiplication of decorated intervals
  * Fixed a linking error in mkoctfile that could prevent package
    installation (bug #45280)
* Sun May 31 2015 dmitry_r@opensuse.org
- Update to version 0.2.1
  * plot, plot3: New interval plotting functions. Pay attention to the
    included examples, which can be executed with 'demo @infsup/plot'
    and 'demo @infsup/plot3' respectively.
  * polyval: New interval arithmetic algorithm
  * bisect: New set operation for bisecting algorithms
  * sinrev, cosrev, tanrev, atan2rev1, atan2rev2: Now allow non-scalar
    arguments
  * Simplified licensing: Relicensed parts of the software that were
    not under GPL
  * Updated information for citation of the package
* Mon May  4 2015 dmitry_r@opensuse.org
- Update to version 0.2.0
  * User manual included in the package
  * New utility functions: cat, postpad, prepad, reshape, resize
  * and, or: Removed deprecated functions
  * Improved display output for cell arrays and new function: disp
  * Minor performance improvements (all decorated interval functions,
    horzcat, vertcat)
  * Bugfixes
* Wed Apr  8 2015 dmitry_r@opensuse.org
- Update to version 0.1.5
  * Implicit decoration of bare intervals triggers a warning now and
    can be allowed or forbidden by the user.  Implicit decoration
    of bare interval literals is not affected.
  * newdec: New operation for explicit promotion of bare intervals
    into decorated intervals (without warning).
  * Decorated interval literals with illegal decoration are
    no longer allowed and produce NaIs.
  * hull: In contrast to the union function, the interval constructor
    is no longer considered a set operation and can create intervals
    with a non-trivial decoration.
  * setdiff, setxor: New set operations
  * intersect, union: Renamed set operations; the old function names (and, or)
  are hereby deprecated and are going to be removed in the next release.
  * intervaltotext, intervaltoexact: Decimal fractions no longer omit zero
    before the point, and unnecessary trailing decimal places can be omitted
    more consistently and in more cases than before (also affects console
    output). Improved accuracy and performance with support for interval
    matrices.
* Thu Mar 19 2015 dmitry_r@opensuse.org
- Update to version 0.1.4
  * New interval constructors: hull, midrad
  * New interval arithmetic functions: cbrt, cot, coth, csc, csch,
    dilog, ei, erf, erfc, gamma, gammaln, psi, rsqrt, sec, sech
  * mtimes: Support for fast, less accurate evaluation using BLAS routines
  * mldivide, mrdivide, inv: Improved performance by using faster mtimes
  * infsup, infsupdec: Enabled broadcasting of scalar boundaries
  * rad: May compute mid and rad simultaneously
  * subsref: Access to interval properties using field syntax: x.inf and x.sup
* Thu Feb 26 2015 dmitry_r@opensuse.org
- Split from octave-forge package, version 0.1.3
